@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-84d671f4a4813d5e21773c05bb378267
-key: yesod_9btgpqWEDkb2qUgVKrBLcH
+id: yesod-1.4.2-cf54ac8d6eb4d9105572f96531f5239b
+key: yesod_A7UlYB5EUo9GyIvhyZIq8a
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,37 +21,37 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-9btgpqWEDkb2qUgVKrBLcH
+hs-libraries: HSyesod-1.4.2-A7UlYB5EUo9GyIvhyZIq8a
 depends:
     aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
     blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.10.1-e4383b2e14cc80179dd5007ca51887df
+    conduit-extra-1.1.11-b294a7608a3a066998e74974ec65ff9b
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-1a8cc90bb0cf2afc03da9e875eb23203
+    monad-logger-0.3.18-ff79344a77beba20df980e6518219c42
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
     shakespeare-2.0.7-299569683f963ce6b42dbe4d7cdb1dae
-    streaming-commons-0.1.15.1-aa72527d91e580265833d7825d2659ed
+    streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    wai-extra-3.0.14.1-048a6fe5f08082cf473c90446f630ef3
+    wai-extra-3.0.14.1-3d73c8398a11a38d4e003b75a7dec448
     wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
-    warp-3.2.3-0572492b8a7d95a6249d079a8975f899
-    yaml-0.8.16-6c308454b5ac62fa4195e7f56277be05
-    yesod-auth-1.4.12-ee3d41f28307a05c0f72f6763eadee03
-    yesod-core-1.4.19-25fb856b7d20f03518ef74f7c04b9148
-    yesod-form-1.4.6-1f5bbab0daee91a31c9792276fdb63be
-    yesod-persistent-1.4.0.3-94cd901c0d8cf92080c629833de6573c
+    warp-3.2.3-f00ff5bb4c1a36e982e04bfba3bef2ca
+    yaml-0.8.16-9d8e48229c43339be2171b93f8cd276c
+    yesod-auth-1.4.12-bd2dbd422b8b288b6daf1ac8f5cb89f3
+    yesod-core-1.4.19-824bf74cd5ec378da568ce71e584e959
+    yesod-form-1.4.6-cc7fd5c2de84bb46c0f6247cd76452a8
+    yesod-persistent-1.4.0.3-cff443ae4acaed8c9376536a5719bdb9
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
